@@ -4,23 +4,24 @@ import itertools
 import json
 import os.path
 import re
+import sys
 from collections import defaultdict
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Callable, Dict, Generator, Iterable, List, Tuple, Type, Union
 
-import json_to_models
-from json_to_models.dynamic_typing import ModelMeta, register_datetime_classes
-from json_to_models.generator import MetadataGenerator
-from json_to_models.models import ModelsStructureType
-from json_to_models.models.attr import AttrsModelCodeGenerator
-from json_to_models.models.base import GenericModelCodeGenerator, generate_code
-from json_to_models.models.dataclasses import DataclassModelCodeGenerator
-from json_to_models.models.structure import compose_models, compose_models_flat
-from json_to_models.registry import (
+from . import __version__ as VERSION
+from .dynamic_typing import ModelMeta, register_datetime_classes
+from .generator import MetadataGenerator
+from .models import ModelsStructureType
+from .models.attr import AttrsModelCodeGenerator
+from .models.base import GenericModelCodeGenerator, generate_code
+from .models.dataclasses import DataclassModelCodeGenerator
+from .models.structure import compose_models, compose_models_flat
+from .registry import (
     ModelCmp, ModelFieldsEquals, ModelFieldsNumberMatch, ModelFieldsPercentMatch, ModelRegistry
 )
-from json_to_models.utils import convert_args
+from .utils import convert_args
 
 STRUCTURE_FN_TYPE = Callable[[Dict[str, ModelMeta]], ModelsStructureType]
 bool_js_style = lambda s: {"true": True, "false": False}.get(s, None)
@@ -75,7 +76,9 @@ class Cli:
             (model_name, (lookup, Path(path)))
             for model_name, lookup, path in namespace.list or ()
         ]
+        self.output_file = namespace.output
         self.enable_datetime = namespace.datetime
+        disable_unicode_conversion = namespace.disable_unicode_conversion
         self.strings_converters = namespace.strings_converters
         merge_policy = [m.split("_") if "_" in m else m for m in namespace.merge]
         structure = namespace.structure
@@ -88,7 +91,7 @@ class Cli:
         self.validate(models, models_lists, merge_policy, framework, code_generator)
         self.setup_models_data(models, models_lists)
         self.set_args(merge_policy, structure, framework, code_generator, code_generator_kwargs_raw,
-                      dict_keys_regex, dict_keys_fields)
+                      dict_keys_regex, dict_keys_fields, disable_unicode_conversion)
 
     def run(self):
         if self.enable_datetime:
@@ -104,7 +107,23 @@ class Cli:
         registry.merge_models(generator)
         registry.generate_names()
         structure = self.structure_fn(registry.models_map)
-        return generate_code(structure, self.model_generator, class_generator_kwargs=self.model_generator_kwargs)
+        output = self.version_string + \
+                 generate_code(structure, self.model_generator, class_generator_kwargs=self.model_generator_kwargs)
+        if self.output_file:
+            with open(self.output_file, "w", encoding="utf-8") as f:
+                f.write(output)
+            return f"Output is written to {self.output_file}"
+        else:
+            return output
+
+    @property
+    def version_string(self):
+        return (
+            'r"""\n'
+            f'generated by json2python-models v{VERSION} at {datetime.now().ctime()}\n'
+            f'command: {" ".join(sys.argv)}\n'
+            '"""\n'
+        )
 
     def validate(self, models, models_list, merge_policy, framework, code_generator):
         """
@@ -149,9 +168,17 @@ class Cli:
             for model_name, list_of_gen in models_dict.items()
         }
 
-    def set_args(self, merge_policy: List[Union[List[str], str]],
-                 structure: str, framework: str, code_generator: str, code_generator_kwargs_raw: List[str],
-                 dict_keys_regex: List[str], dict_keys_fields: List[str]):
+    def set_args(
+            self,
+            merge_policy: List[Union[List[str], str]],
+            structure: str,
+            framework: str,
+            code_generator: str,
+            code_generator_kwargs_raw: List[str],
+            dict_keys_regex: List[str],
+            dict_keys_fields: List[str],
+            disable_unicode_conversion: bool
+    ):
         """
         Convert CLI args to python representation and set them to appropriate object attributes
         """
@@ -175,6 +202,7 @@ class Cli:
             self.model_generator = getattr(m, cls)
 
         self.model_generator_kwargs = {} if not self.strings_converters else {'post_init_converters': True}
+        self.model_generator_kwargs['convert_unicode'] = not disable_unicode_conversion
         if code_generator_kwargs_raw:
             for item in code_generator_kwargs_raw:
                 if item[0] == '"':
@@ -216,6 +244,11 @@ class Cli:
                  "I.e. for file that contains dict {\"a\": {\"b\": [model_data, ...]}} you should\n"
                  "pass 'a.b' as <JSON key>.\n\n"
         )
+        parser.add_argument(
+            "-o", "--output",
+            metavar="FILE", default="",
+            help="Path to output file\n\n"
+        )
         parser.add_argument(
             "-f", "--framework",
             default="base",
@@ -243,6 +276,11 @@ class Cli:
             action="store_true",
             help="Enable generation of string types converters (i.e. IsoDatetimeString or BooleanString).\n\n"
         )
+        parser.add_argument(
+            "--disable-unicode-conversion", "--no-unidecode",
+            action="store_true",
+            help="Disabling unicode conversion in fields and class names.\n\n"
+        )
 
         default_percent = f"{ModelFieldsPercentMatch.DEFAULT * 100:.0f}"
         default_number = f"{ModelFieldsNumberMatch.DEFAULT:.0f}"
@@ -250,15 +288,17 @@ class Cli:
             "--merge",
             default=["percent", "number"],
             nargs="+",
-            help=f"Merge policy settings. Default is 'percent_{default_percent} number_{default_number}' (percent of field match\n"
-                 "or number of fields match).\n"
-                 "Possible values are:\n"
-                 "'percent[_<percent>]' - two models had a certain percentage of matched field names.\n"
-                 f"                        Default percent is {default_percent}%%. "
-                 "Custom value could be i.e. 'percent_95'.\n"
-                 "'number[_<number>]'   - two models had a certain number of matched field names.\n"
-                 f"                        Default number of fields is {default_number}.\n"
-                 "'exact'               - two models should have exact same field names to merge.\n\n"
+            help=(
+                f"Merge policy settings. Default is 'percent_{default_percent} number_{default_number}' (percent of field match\n"
+                "or number of fields match).\n"
+                "Possible values are:\n"
+                "'percent[_<percent>]' - two models had a certain percentage of matched field names.\n"
+                f"                        Default percent is {default_percent}%%. "
+                "Custom value could be i.e. 'percent_95'.\n"
+                "'number[_<number>]'   - two models had a certain number of matched field names.\n"
+                f"                        Default number of fields is {default_number}.\n"
+                "'exact'               - two models should have exact same field names to merge.\n\n"
+            )
         )
         parser.add_argument(
             "--dict-keys-regex", "--dkr",
@@ -293,8 +333,7 @@ class Cli:
         return parser
 
 
-def main(version_string=None):
-    import sys
+def main():
     import os
 
     if os.getenv("TRAVIS", None) or os.getenv("FORCE_COVERAGE", None):
@@ -305,14 +344,7 @@ def main(version_string=None):
 
     cli = Cli()
     cli.parse_args()
-    if not version_string:
-        version_string = (
-            'r"""\n'
-            f'generated by json2python-models v{json_to_models.__version__} at {datetime.now().ctime()}\n'
-            f'command: {" ".join(sys.argv)}\n'
-            '"""\n'
-        )
-    print(version_string + cli.run())
+    print(cli.run())
 
 
 def path_split(path: str) -> List[str]:
@@ -374,7 +406,7 @@ def safe_json_load(path: Path) -> Union[dict, list]:
     """
     Open file, load json and close it.
     """
-    with path.open() as f:
+    with path.open(encoding="utf-8") as f:
         return json.load(f)
 
 
